@@ -53,7 +53,7 @@ class Alias(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["AliasProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[AliasProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -155,7 +155,7 @@ class Key(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Optional[typing.Union["KeyProps", typing.Dict[str, typing.Any]]] = None,
+                props: typing.Optional[typing.Union[KeyProps, typing.Dict[str, typing.Any]]] = None,
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -378,7 +378,7 @@ class RosAlias(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosAliasProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosAliasProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -562,7 +562,7 @@ class RosKey(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosKeyProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosKeyProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1017,7 +1017,7 @@ class RosSecret(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosSecretProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosSecretProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1544,7 +1544,7 @@ class Secret(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["SecretProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[SecretProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
